@@ -7,6 +7,8 @@
 #' @param data_type Either 'long' (as made by  \code{\link{simulate_data}}) or 'compact' (as made by \code{\link{collapse_data}}).
 #'  Compact data must have entries for each member of each strategy family to produce a valid simplex.
 #' @param keep_fit Logical. Whether to append the  \code{\link[rstan]{stanfit}} object to the model. Defaults to `FALSE`
+#' @param keep_transformed Logical. Whether to keep transformed parameters, prob_of_types, P_lambdas, w, w_full
+#' @param censored_types vector of data types that are selected out of the data, eg c("X0Y0")
 #' @param ... Options passed onto \code{\link[rstan]{stan}} call.
 #' @return An object of class \code{causal_model}. It essentially returns a list containing the elements comprising
 #' a model (e.g. 'statement', 'nodal_types' and 'DAG') with the `posterior_distribution` returned by \code{\link[rstan]{stan}} attached to it.
@@ -25,6 +27,9 @@
 #'\donttest{
 #' model_1 <- update_model(model, data_long)
 #'}
+#'\donttest{
+#' model_2 <- update_model(model, data_long, keep_transformed = FALSE)
+#'}
 #'\dontrun{
 #' # Throws error unless compact data indicated:
 #'
@@ -35,37 +40,22 @@
 #'
 #' # It is possible to implement updating without data, in which case the posterior
 #' # is a stan object that reflects the prior
-#' model5 <- update_model(model)
-#'
-#' # Advanced: Example of a model with tailored parameters.
-#' # We take a model and add a tailored P matrix (which maps from parameters
-#' # to causal types) and a tailored parameters_df which reports that
-#' # all parameters are in one family.
-#' # Parameters in this example are not connected with nodal types in any way.
-#' model <- make_model('X->Y')
-#' P <- diag(8)
-#' colnames(P) <- rownames(model$causal_types)
-#' model <- set_parameter_matrix(model, P = P)
-#' model$parameters_df <- data.frame(
-#'   param_names = paste0('x',1:8),
-#'   param_set = 1, priors = 1, parameters = 1/8)
+#' model_5 <- update_model(model)
 #'
 #'
-#' # Update fully confounded model on strongly correlated data
+#' # Censored data types
+#' make_model("X->Y") %>%
+#'   update_model(data.frame(X=c(1,1), Y=c(1,1)), censored_types = c("X1Y0")) %>%
+#'   query_model(te("X", "Y"), using = "posteriors")
 #'
-#' data <- make_data(make_model('X->Y'), n = 100,
-#'   parameters = c(.5, .5, .1,.1,.7,.1))
-#' fully_confounded <- update_model(model, data, keep_fit = TRUE)
-#' fully_confounded$stan_fit
-#' query_model(fully_confounded, 'Y[X = 1] > Y[X=0]', using = 'posteriors')
-#' # To see the confounding:
-#' with(fully_confounded$posterior_distribution %>% data.frame(),
-#' {par(mfrow = c(1,2))
-#'  plot(x1, x5, main = 'joint distribution of X0.Y00, X0.Y01')
-#'  plot(x1, x6, main = 'joint distribution of X0.Y00, X1.Y01')})
-#' }
-#'
-update_model <- function(model, data = NULL, data_type = "long", keep_fit = FALSE, ...) {
+#'# Censored data: Learning nothing
+#' make_model("X->Y") %>%
+#'   update_model(data.frame(X=c(1,1), Y=c(1,1)), censored_types = c("X1Y0", "X0Y0", "X0Y1")) %>%
+#'   query_model(te("X", "Y"), using = "posteriors")
+#'   }
+
+update_model <- function(model, data = NULL, data_type = "long", keep_fit = FALSE,
+                         keep_transformed = TRUE, censored_types = NULL, ...) {
 
     if (data_type == "long") {
 
@@ -98,21 +88,32 @@ update_model <- function(model, data = NULL, data_type = "long", keep_fit = FALS
         data_events <- data
     }
 
-    stan_data <- prep_stan_data(model = model, data = data_events)
+    stan_data <- prep_stan_data(model = model,
+                                data = data_events,
+                                keep_transformed = keep_transformed*1)
+
+    # Parmpa goes to 0 for data types that never get to be observed
+    if(!is.null(censored_types))
+    stan_data$parmap[, censored_types] <- 0
 
     # assign fit
     stanfit <- stanmodels$simplexes
+
     sampling_args <- set_sampling_args(object = stanfit, user_dots = list(...), data = stan_data)
     newfit <- do.call(rstan::sampling, sampling_args)
 
-    if (keep_fit)
-        model$stan_fit <- newfit
+    model$stan_objects  <- list(data = data)
 
-    posterior_distribution <- extract(newfit, pars = "lambdas")$lambdas
-    colnames(posterior_distribution) <- get_parameter_names(model)
+    if(keep_fit) model$stan_objects$stan_fit <- newfit
 
-    model$posterior_distribution <- posterior_distribution
-    model$data <- data
+    model$posterior_distribution <- extract(newfit, pars = "lambdas")$lambdas
+    colnames(model$posterior_distribution) <- get_parameter_names(model)
+
+    model$stan_objects$type_distribution <- extract(newfit, pars = "prob_of_types")$prob_of_types
+        colnames(model$stan_objects$type_distribution) <- colnames(stan_data$P)
+
+    model$stan_objects$w_full <- extract(newfit, pars = "w_full")$w_full
+        colnames(model$stan_objects$w_full) <- rownames(stan_data$E)
 
     model
 }
