@@ -1,12 +1,15 @@
 
-.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
 
-if (.runThisTest) {
+
+
 
 context("Testing set_parameter_matrix")
 
+testthat::skip_on_cran()
 testthat::test_that(
+
 	desc = "Testing messages.",
+
 	code = {
 		model <- make_model("X <- Y")
 		model <- set_parameter_matrix(model)
@@ -17,8 +20,11 @@ testthat::test_that(
 
 context("Testing summary commands for set_parameter_matrix")
 
+testthat::skip_on_cran()
 testthat::test_that(
+
 	desc = "Testing print.",
+
 	code = {
 		model <- make_model("X -> Y")
 		model <- set_parameter_matrix(model)
@@ -28,7 +34,9 @@ testthat::test_that(
 )
 
 testthat::test_that(
+
 	desc = "Testing summary.",
+
 	code = {
 		model <- make_model("X -> Y")
 		confound <- list(X = "(Y[X=1] > Y[X=0])", X = "(Y[X=1] == 1)")
@@ -38,5 +46,5 @@ testthat::test_that(
 		expect_true(any(grepl(" parameter set", out)))
 	}
 )
-}
+
 
